load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

begin

vname = (/"lambda1","lambda2"/)
filename_1 = (/"lambda1-sgs-size3-2deg-1yr-2008.nc","lambda1-Rynlds-size3-2deg-1yr-2008.nc",\
            "lambda1-nonRynlds-size3-2deg-1yr-2008.nc",\
            "lambda1-stationary-size3-2deg-1yr-2008.nc","stationary-lambda1-Rynlds-size3-2deg-1yr-2008.nc",\
            "stationary-lambda1-nonRynlds-size3-2deg-1yr-2008.nc",\ 
            "lambda1-transient-size3-2deg-1yr-2008.nc","transient-lambda1-Rynlds-size3-2deg-1yr-2008.nc",\
            "transient-lambda1-nonRynlds-size3-2deg-1yr-2008.nc"/)
filename_2 = (/"lambda2-sgs-size3-2deg-1yr-2008.nc","lambda2-Rynlds-size3-2deg-1yr-2008.nc",\
            "lambda2-nonRynlds-size3-2deg-1yr-2008.nc",\
            "lambda2-stationary-size3-2deg-1yr-2008.nc","stationary-lambda2-Rynlds-size3-2deg-1yr-2008.nc",\
            "stationary-lambda2-nonRynlds-size3-2deg-1yr-2008.nc",\ 
            "lambda2-transient-size3-2deg-1yr-2008.nc","transient-lambda2-Rynlds-size3-2deg-1yr-2008.nc",\
            "transient-lambda2-nonRynlds-size3-2deg-1yr-2008.nc"/)

pic_name = "figureC8"
dir = "../SOSE/K_tensor-2deg/eigen/"
fig_dir = "./"
plot1 = new((/3/),graphic)
plot = new((/2/),graphic)
base = new((/4/),graphic)
panel = new((/2/),graphic)
p1=new((/9/),double)
p2=new((/9/),double)
p3=new((/9/),double)
bars=new((/9,5/),double) ;;10 percentile,mean-1sigma,mean,mean+1sigma,90 percentile
all_num = 320*2160
pos_pos=new((/all_num/),double)
pos_neg=new((/all_num/),double)
neg_neg=new((/all_num/),double)
epsln=1e-10

ff=addfile(dir+"zz_topo/outcrop-counter-sose-2008.nc", "r")
daynum=ff->daynum(0,2,:,0:2159)
daynum = (daynum/73.0)*100.0

do ivar=0,8

  f1=addfile(dir+filename_1(ivar),"r")
  lambda1=f1->$vname(0)$(0,2,:,0:2159) 
  lambda1 = where(abs(daynum).lt.1.0, lambda1, lambda1@_FillValue)
  print(dimsizes(lambda1))
  print(max(lambda1))

  f2=addfile(dir+filename_2(ivar),"r")
  lambda2=f2->$vname(1)$(0,2,:,0:2159) 
  lambda2 = where(abs(daynum).lt.1.0, lambda2, lambda2@_FillValue)
  print(lambda2(150,1400))


  wrk=where((abs(lambda1).lt.1e5).and.(abs(lambda2).lt.1e5),1.0,0.0)
  print(wrk(150,1400))
  wrk1=where((abs(lambda1).lt.1e5).and.(abs(lambda2).lt.1e5).and.(lambda1.gt.0.0).and.(lambda2.lt.0.0),1.0,0.0)
  wrk2=where((abs(lambda1).lt.1e5).and.(abs(lambda2).lt.1e5).and.(lambda1.gt.0.0).and.(lambda2.gt.0.0),1.0,0.0)
  wrk3=where((abs(lambda1).lt.1e5).and.(abs(lambda2).lt.1e5).and.(lambda1.lt.0.0).and.(lambda2.lt.0.0),1.0,0.0)
  print(wrk1(150,1400))
  print(wrk2(150,1400))
  print(wrk3(150,1400))
  print(dimsizes(wrk3))


  sum_all=sum(wrk(:,:))
  sum_1=sum(wrk1(:,:))
  sum_2=sum(wrk2(:,:))
  sum_3=sum(wrk3(:,:))
  p1(ivar)=sum_1/sum_all
  p2(ivar)=sum_2/sum_all
  p3(ivar)=sum_3/sum_all


end do ;;ivar loop


;;=========================== plot ==============================
;wks=gsn_open_wks("pdf",fig_dir+pic_name)
wks=gsn_open_wks("png",fig_dir+pic_name)

res = True
res@gsnDraw               = False
res@gsnFrame              = False

res@vpWidthF              = 0.75
res@vpHeightF             = 0.2

res@trXMinF               = 0.0
res@trXMaxF               = 23.0
res@trYMinF               = 0.0
res@trYMaxF               = 1.0

res@gsnXYBarChart         = True
res@gsnXYBarChartBarWidth = 0.5           ; change bar widths

res@tmXBMode              = "Explicit"         ; explicit labels
res@tmXBValues            = fspan(1.0,22.0,9)
res@tmXBLabels            = (/"sfs-ttl","Rynlds-ttl","nonRynlds-ttl",\
                              "sfs-stt","Rynlds-stt","nonRynlds-stt",\
                              "sfs-trs","Rynlds-trs","nonRynlds-trs"/)
res@tmXBLabelFontHeightF  = 0.015
res@tmXBLabelAngleF = 30

res@tmXTOn=False
res@tmYROn=False

res@tmYLMode              = "Explicit"         ; explicit labels
res@tmYLValues            = ispan(0,10,1)/10.0
res@tmYLLabels            = (/"0.0","","","0.3","","","0.6","","","0.9",""/)
res@tmYLLabelFontHeightF  = 0.015

res@gsnRightString        = ""
;res@tiYAxisString         = "frequency"
;res@tiYAxisFontHeightF = 0.02


res@gsnXYBarChartColors = "red"
plot1(0) = gsn_csm_xy(wks,fspan(0.5,21.5,9),p2(:),res)

res@gsnXYBarChartColors = "green"
plot1(1) = gsn_csm_xy(wks,fspan(1.0,22.0,9),p1(:),res)

res@gsnXYBarChartColors = "blue"
plot1(2) = gsn_csm_xy(wks,fspan(1.5,22.5,9),p3(:),res)

; Overlay the last three plot on the first one.
do j=1,2
 overlay(plot1(0),plot1(j))
end do

; Create some labelbars for a legend
lbres                    = True          ; labelbar only resources
lbres@vpWidthF           = 0.2           ; labelbar width
lbres@vpHeightF          = 0.1           ; labelbar height
lbres@lbBoxMajorExtentF  = 0.15          ; puts space between color boxes
lbres@lbMonoFillPattern  = True          ; Solid fill pattern
lbres@lbLabelFontHeightF = 0.02         ; font height. default is small
lbres@lbLabelJust        = "CenterLeft"  ; left justify labels
lbres@lbPerimOn          = False

colors = (/"red",  "green", "blue"/)
labels = (/"(+,+)", "(+,-)", "(-,-)"/)
xpos   = (/0.26, 0.46, 0.66/)

do ivar=0,2
   lbres@lbFillColors = colors(ivar)
   gsn_labelbar_ndc(wks,1,labels(ivar),xpos(ivar),0.9,lbres)
end do 

panel(0)=plot1(0)


;;=====================================================================
;;=====================================================================
ff=addfile(fig_dir+"lambda-statistics-bars.nc", "r")
bars_wrk=ff->bars
print(bars_wrk)
bars2=transpose((bars_wrk))
print(bars2)

;;=========================== plot ==============================
  res1            = True
  res1@vpWidthF              = 0.75
  res1@vpHeightF             = 0.3

  res1@trXMinF               = -1.0
  res1@trXMaxF               = 24.0
  res1@trYMinF               = -3.0
  res1@trYMaxF               = 3.0

  res1@tmXBMode              = "Explicit"         ; explicit labels
  res1@tmXBValues            = fspan(-1.5,22.0,10)
  res1@tmXBLabels            = (/"sfs-ttl","Rynlds-ttl","nonRynlds-ttl",\
                                "sfs-stt","Rynlds-stt","nonRynlds-stt",\
                                "sfs-trs","Rynlds-trs","nonRynlds-trs"/)
  res1@tmXBLabelFontHeightF  = 0.015
  res1@tmXBLabelAngleF = 30

  res1@tmXTOn=False
  res1@tmYROn=False
  res1@tmYLMinorOn=False
  res1@tmYLMajorLengthF=0.005
  res1@tmYLLabelFontHeightF  = 0.015
  ;res1@gsnYRefLine=0.0
  ;res1@gsnYRefLine=1.0
  ;res1@gsnYRefLine=-1.0
  ;res1@gsnYRefLineColor="black"

  ;res1@tmYLMode              = "Explicit"         ; explicit labels
  ;res1@tmYLValues            = ispan(0,10,1)/10.0
  ;res1@tmYLLabels            = (/"0.0","","","0.3","","","0.6","","","0.9",""/)
  ;res1@tmYLLabelFontHeightF  = 0.015                      

  llres                   = True      
  llres@gsLineThicknessF  = 5                ; line thickness 

  opti          = True      
  opti@boxWidth = .5       ; Width of box (x units)
  opti@boxColors = "red"
  plot(1) = boxplot(wks,fspan(0.4,21.4,9),bars2(:,0,:),opti,res1,llres) 
  opti@boxColors = "green"
  base(0) = boxplot(wks,fspan(1.0,22.0,9),bars2(:,1,:),opti,res1,llres) 
  opti@boxColors = "blue"
  base(1) = boxplot(wks,fspan(1.6,22.6,9),bars2(:,2,:),opti,res1,llres) 

; Overlay the last three plot on the first one.
do j=0,1
 overlay(plot(1),base(j))
end do

lnres=True
lnres@gsLineColor="black"
lnres@gsLineThicknessF=3.0
lnres@gsLineDashPattern=2
xx=fspan(-0.5,23.5,9)
yy=xx*0.0
yy1=xx*0.0+1.0
yy2=xx*0.0-1.0
yy3=xx*0.0+2.0
yy4=xx*0.0-2.0
dum1 = gsn_add_polyline(wks, plot(1), xx, yy, lnres)
dum2 = gsn_add_polyline(wks, plot(1), xx, yy1, lnres)
dum3 = gsn_add_polyline(wks, plot(1), xx, yy2, lnres)
dum4 = gsn_add_polyline(wks, plot(1), xx, yy3, lnres)
dum5 = gsn_add_polyline(wks, plot(1), xx, yy4, lnres)

panel(1)=plot(1)

pres = True
pres@txString = ""
pres@gsnPanelLabelBar = False
pres@gsnPanelFigureStrings = (/"(a)","(b)"/)
pres@gsnPanelFigureStringsFontHeightF=0.02
pres@gsnPanelFigureStringsPerimOn = False
pres@amJust = "Topleft"
;pres@lbLabelFontHeightF = 0.015
;pres@lbLabelStride = 1
gsn_panel(wks,panel,(/2,1/),pres)


;draw(plot(0))
;frame(wks)   ; Advance the frame.

end
