load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

begin

varnames = (/"lambda1","lambda2","alpha","beta"/)
file_1 = (/"lambda1-sgs-2deg-1yr-0063.nc",\
          "lambda2-sgs-2deg-1yr-0063.nc",\
          "alpha-PV-sgs-2deg-1yr-0063.nc",\
          "beta-PV-sgs-2deg-1yr-0063.nc"/)

file_2 = (/"lambda1-stationary-2deg-1yr-0063.nc",\
          "lambda2-stationary-2deg-1yr-0063.nc",\
          "alpha-PV-stationary-2deg-1yr-0063.nc",\
          "beta-PV-stationary-2deg-1yr-0063.nc"/)

file_3 = (/"lambda1-transient-2deg-1yr-0063.nc",\
          "lambda2-transient-2deg-1yr-0063.nc",\
          "alpha-PV-transient-2deg-1yr-0063.nc",\
          "beta-PV-transient-2deg-1yr-0063.nc"/)

pic_name = "figureS6"
var_label = "-sfs"
label = (/"(a) lambda1-ttl","(b) lambda1-stt","(c) lambda1-trs",\
          "(d) lambda2-ttl","(e) lambda2-stt","(f) lambda2-trs"/)

dir = "../LICOM/eigen/"
fig_dir = "./"
pi=3.14159265
base = new(6,graphic)
plotv = new(6,graphic)

setfileoption("nc","Format","LargeFile")
setvalues NhlGetWorkspaceObjectId()
  "wsMaximumSize": 600000000
end setvalues

;;========================================================
wks_type="png"
wks_type@wkWidth=10000
wks_type@wkHeight=10000
wks=gsn_open_wks(wks_type,fig_dir+pic_name)
gsn_define_colormap(wks,"ncl_default")

;;---------------------------------------------;;
values = fspan(-8000,8000,101)

fill = new(102,integer)
fill_wrk = fspan(15,125,51)
fill(0:50) = floattoint(fill_wrk)
fill_wrk = fspan(130,240,51)
fill(51:101) = floattoint(fill_wrk)
;print(fill)
;;---------------------------------------------;;
;;=======================================================
resv=True
resv@gsnDraw=False
resv@gsnFrame=False
resv@gsnAddCyclic=False
resv@gsnLeftString=""
resv@gsnRightString=""

resv@vcPositionMode            = "ArrowCenter"  
resv@vcGlyphStyle              = "Fillarrow"  
resv@vcFillArrowEdgeThicknessF = 0.5        
resv@vcFillArrowEdgeColor      = "white"   
resv@vcFillArrowFillColor      = "black"  
resv@vcFillArrowWidthF         = 0.2     
resv@vcFillArrowHeadXF         = 0.01       
resv@vcFillArrowHeadYF         = 0.001      
resv@vcFillArrowHeadInteriorXF = 0.001     
         
resv@vcMinDistanceF            = 0.01    
; resv@vcMinMagnitudeF           = 1.0    

resv@vcFillArrowMinFracWidthF =1.0 
resv@vcFillArrowHeadMinFracXF =1.0  
resv@vcFillArrowHeadMinFracYF =1.0 

resv@vcRefAnnoOn               = False 
resv@vcRefMagnitudeF           = 1.0  
resv@vcRefLengthF              = 0.005   
;;=========================================================

res = True
res@gsnDraw=False
res@gsnFrame=False
res@gsnAddCyclic=False
res@gsnCenterString="" ;;for zz and hh
res@gsnLeftStringFontHeightF = 0.012
;res@gsnLeftString=label(nlev*4)
res@gsnRightString=""

res@mpCenterLonF=180
res@mpMaxLonF=359
res@mpMinLonF=1
res@mpMaxLatF=-25
res@mpMinLatF=-75
res@mpMonoFillColor = True
res@mpFillColor = "gray79"
res@cnFillOn=True
res@cnLinesOn=False
;res@cnLineThicknessF=0.1
; res@cnLevelSelectionMode="ManualLevels"
; res@cnMaxLevelValF=var_max
; res@cnMinLevelValF=var_min
; res@cnLevelSpacingF=spa
res@cnLevelSelectionMode="ExplicitLevels"
res@cnLevels       = values
res@cnFillColors       = fill
; res@cnLevelSelectionMode="ExplicitLevels"
; res@cnLevels       = (/-3000,-2500,-2000,-1500,-1000,-500,0,500,1000,1500,2000,2500,3000/)
; res@cnFillColors       = (/10,20,35,50,65,80,110,    140,153,170,190,205,217,230/)

res@cnFillMode = "RasterFill"
res@lbLabelBarOn = False
res@lbBoxLinesOn=False
; res@lbLabelFontHeightF = 0.01
; res@lbLabelStride = 1
; res@pmLabelBarOrthogonalPosF=0.11
res@tmXBLabelFontHeightF=0.0075
res@tmXBLabelDeltaF=-0.5
res@tmYLLabelFontHeightF=0.0075
res@tmYLLabelDeltaF=-0.5
;;----------------------------------------



f1=addfile(dir+file_1(0),"r")  ;;total-lambda1
var1=f1->$varnames(0)$(0,0,:,0:3599) ;;lambda1
var1 = where(abs(var1).lt.1.0e10, var1, var1@_FillValue)
ff1=addfile(dir+file_1(2),"r")  ;;alpha
angle1=ff1->$varnames(2)$(0,0,:,0:3599)
angle1 = where(abs(angle1).lt.1.0e10, angle1, angle1@_FillValue)
vec1_1 = cos(angle1/180.0*pi)
vec1_2 = sin(angle1/180.0*pi)
copy_VarMeta(angle1,vec1_1)
copy_VarMeta(angle1,vec1_2)
res@gsnLeftString=label(0)+var_label
base(0)=gsn_csm_contour_map(wks,var1,res)  
plotv(0)=gsn_csm_vector(wks,vec1_1,vec1_2,resv)
overlay(base(0),plotv(0))
delete([/f1,ff1,var1,angle1,vec1_1,vec1_2/])


f2=addfile(dir+file_2(0),"r")  ;;stt-lambda1
var2=f2->$varnames(0)$(0,0,:,0:3599) ;;lambda1
var2 = where(abs(var2).lt.1.0e10, var2, var2@_FillValue)
ff2=addfile(dir+file_2(2),"r")  ;;alpha
angle2=ff2->$varnames(2)$(0,0,:,0:3599)
angle2 = where(abs(angle2).lt.1.0e10, angle2, angle2@_FillValue)
vec2_1 = cos(angle2/180.0*pi)
vec2_2 = sin(angle2/180.0*pi)
copy_VarMeta(angle2,vec2_1)
copy_VarMeta(angle2,vec2_2)
res@gsnLeftString=label(1)+var_label
base(1)=gsn_csm_contour_map(wks,var2,res)  
plotv(1)=gsn_csm_vector(wks,vec2_1,vec2_2,resv)
overlay(base(1),plotv(1))
delete([/f2,ff2,var2,angle2,vec2_1,vec2_2/])



f3=addfile(dir+file_3(0),"r")  ;;trs-lambda1
var3=f3->$varnames(0)$(0,0,:,0:3599) ;;lambda1
var3 = where(abs(var3).lt.1.0e10, var3, var3@_FillValue)
ff3=addfile(dir+file_3(2),"r")  ;;alpha
angle3=ff3->$varnames(2)$(0,0,:,0:3599)
angle3 = where(abs(angle3).lt.1.0e10, angle3, angle3@_FillValue)
vec3_1 = cos(angle3/180.0*pi)
vec3_2 = sin(angle3/180.0*pi)
copy_VarMeta(angle3,vec3_1)
copy_VarMeta(angle3,vec3_2)
res@gsnLeftString=label(2)+var_label
base(2)=gsn_csm_contour_map(wks,var3,res)  
plotv(2)=gsn_csm_vector(wks,vec3_1,vec3_2,resv)
overlay(base(2),plotv(2))
delete([/f3,ff3,var3,angle3,vec3_1,vec3_2/])


f4=addfile(dir+file_1(1),"r")  ;;total-lambda2
var4=f4->$varnames(1)$(0,0,:,0:3599) ;;lambda2
var4 = where(abs(var4).lt.1.0e10, var4, var4@_FillValue)
ff4=addfile(dir+file_1(3),"r")  ;;beta
angle4=ff4->$varnames(3)$(0,0,:,0:3599)
angle4 = where(abs(angle4).lt.1.0e10, angle4, angle4@_FillValue)
vec4_1 = cos(angle4/180.0*pi)
vec4_2 = sin(angle4/180.0*pi)
copy_VarMeta(angle4,vec4_1)
copy_VarMeta(angle4,vec4_2)
res@gsnLeftString=label(3)+var_label
base(3)=gsn_csm_contour_map(wks,var4,res)  
plotv(3)=gsn_csm_vector(wks,vec4_1,vec4_2,resv)
overlay(base(3),plotv(3))
delete([/f4,ff4,var4,angle4,vec4_1,vec4_2/])


f5=addfile(dir+file_2(1),"r")  ;;stt-lambda2
var5=f5->$varnames(1)$(0,0,:,0:3599) ;;lambda2
var5 = where(abs(var5).lt.1.0e10, var5, var5@_FillValue)
ff5=addfile(dir+file_2(3),"r")  ;;beta
angle5=ff5->$varnames(3)$(0,0,:,0:3599)
angle5 = where(abs(angle5).lt.1.0e10, angle5, angle5@_FillValue)
vec5_1 = cos(angle5/180.0*pi)
vec5_2 = sin(angle5/180.0*pi)
copy_VarMeta(angle5,vec5_1)
copy_VarMeta(angle5,vec5_2)
res@gsnLeftString=label(4)+var_label
base(4)=gsn_csm_contour_map(wks,var5,res) 
plotv(4)=gsn_csm_vector(wks,vec5_1,vec5_2,resv)
overlay(base(4),plotv(4))
delete([/f5,ff5,var5,angle5,vec5_1,vec5_2/])


f6=addfile(dir+file_3(1),"r")  ;;trs-lambda2
var6=f6->$varnames(1)$(0,0,:,0:3599) ;;lambda2
var6 = where(abs(var6).lt.1.0e10, var6, var6@_FillValue)
ff6=addfile(dir+file_3(3),"r")  ;;beta
angle6=ff6->$varnames(3)$(0,0,:,0:3599)
angle6 = where(abs(angle6).lt.1.0e10, angle6, angle6@_FillValue)
vec6_1 = cos(angle6/180.0*pi)
vec6_2 = sin(angle6/180.0*pi)
copy_VarMeta(angle6,vec6_1)
copy_VarMeta(angle6,vec6_2)
res@gsnLeftString=label(5)+var_label
base(5)=gsn_csm_contour_map(wks,var6,res)  
plotv(5)=gsn_csm_vector(wks,vec6_1,vec6_2,resv)
overlay(base(5),plotv(5))
delete([/f6,ff6,var6,angle6,vec6_1,vec6_2/])
print("---- line 214 ----")

pres = True
pres@txString = ""
pres@gsnPanelLabelBar = True
; ;pres@gsnPanelFigureStrings = (/"a","b","c","d","e"/)
; ;pres@gsnPanelFigureStringsFontHeightF=0.01
; pres@amJust = "Topleft"
; pres@pmLabelBarWidthF = 0.8
; pres@pmLegendHeightF = 0.6
; pres@pmLabelBarParallelPosF = -0.012
pres@lbLabelFontHeightF = 0.012
pres@lbBoxLinesOn=False
pres@lbLabelStride = 25
gsn_panel(wks,base,(/6,1/),pres)

;draw(a)
;frame(wks)



end
