load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"

begin

varnames = (/"lambda1","lambda2","alpha","beta"/)
file_1 = (/"lambda1-Rynlds-2deg-1yr-0063.nc",\
          "lambda2-Rynlds-2deg-1yr-0063.nc",\
          "alpha-PV-Rynlds-2deg-1yr-0063.nc",\
          "beta-PV-Rynlds-2deg-1yr-0063.nc"/)

file_2 = (/"lambda1-nonRynlds-2deg-1yr-0063.nc",\
          "lambda2-nonRynlds-2deg-1yr-0063.nc",\
          "alpha-PV-nonRynlds-2deg-1yr-0063.nc",\
          "beta-PV-nonRynlds-2deg-1yr-0063.nc"/)

pic_name = "figureS7"
label = (/"(a) lambda1-ttl-Rynlds","(b) lambda1-ttl-nonRynlds",\
         "(c) lambda2-ttl-Rynlds","(d) lambda2-ttl-nonRynlds"/)

dir = "../LICOM/eigen/"
fig_dir = "./"

base = new(4,graphic)
plotv = new(4,graphic)
plot = new(1,graphic)

f1=addfile(dir+file_1(0),"r")  ;;lambda1-Rynlds
f2=addfile(dir+file_2(0),"r")  ;;lambda1-nonRynlds
f3=addfile(dir+file_1(1),"r")  ;;lambda2-Rynlds
f4=addfile(dir+file_2(1),"r")  ;;lambda2-nonRynlds

var1=f1->$varnames(0)$(0,0,:,0:3599) ;;lambda1
var2=f2->$varnames(0)$(0,0,:,0:3599) ;;lambda1
var3=f3->$varnames(1)$(0,0,:,0:3599) ;;lambda2
var4=f4->$varnames(1)$(0,0,:,0:3599) ;;lambda2

print(dimsizes(var1))
var_shape=dimsizes(var1)
print(var1(200,1000))

ff1=addfile(dir+file_1(2),"r")  ;;alpha
ff2=addfile(dir+file_2(2),"r")  ;;alpha
ff3=addfile(dir+file_1(3),"r")  ;;beta
ff4=addfile(dir+file_2(3),"r")  ;;beta

angle1=ff1->$varnames(2)$(0,0,:,0:3599)
angle2=ff2->$varnames(2)$(0,0,:,0:3599)
angle3=ff3->$varnames(3)$(0,0,:,0:3599)
angle4=ff4->$varnames(3)$(0,0,:,0:3599)

pi=3.14159265
vec1_1 = cos(angle1/180.0*pi)
vec1_2 = sin(angle1/180.0*pi)
copy_VarMeta(angle1,vec1_1)
copy_VarMeta(angle1,vec1_2)
vec2_1 = cos(angle2/180.0*pi)
vec2_2 = sin(angle2/180.0*pi)
copy_VarMeta(angle2,vec2_1)
copy_VarMeta(angle2,vec2_2)
vec3_1 = cos(angle3/180.0*pi)
vec3_2 = sin(angle3/180.0*pi)
copy_VarMeta(angle3,vec3_1)
copy_VarMeta(angle3,vec3_2)
vec4_1 = cos(angle4/180.0*pi)
vec4_2 = sin(angle4/180.0*pi)
copy_VarMeta(angle4,vec4_1)
copy_VarMeta(angle4,vec4_2)

;;========================================================
wks_type="png"
wks_type@wkWidth=10000
wks_type@wkHeight=10000
wks=gsn_open_wks(wks_type,fig_dir+pic_name)
gsn_define_colormap(wks,"ncl_default")

;;---------------------------------------------;;
values = fspan(-8000,8000,101)

fill = new(102,integer)
fill_wrk = fspan(15,125,51)
fill(0:50) = floattoint(fill_wrk)
fill_wrk = fspan(130,240,51)
fill(51:101) = floattoint(fill_wrk)
;print(fill)
;;---------------------------------------------;;
;;=======================================================
resv=True
resv@gsnDraw=False
resv@gsnFrame=False
resv@gsnAddCyclic=False
resv@gsnLeftString=""
resv@gsnRightString=""

resv@vcPositionMode            = "ArrowCenter"  
resv@vcGlyphStyle              = "Fillarrow"  
resv@vcFillArrowEdgeThicknessF = 0.5        
resv@vcFillArrowEdgeColor      = "white"   
resv@vcFillArrowFillColor      = "black"  
resv@vcFillArrowWidthF         = 0.2     
resv@vcFillArrowHeadXF         = 0.01       
resv@vcFillArrowHeadYF         = 0.001      
resv@vcFillArrowHeadInteriorXF = 0.001     
         
resv@vcMinDistanceF            = 0.01    
; resv@vcMinMagnitudeF           = 1.0    

resv@vcFillArrowMinFracWidthF =1.0 
resv@vcFillArrowHeadMinFracXF =1.0  
resv@vcFillArrowHeadMinFracYF =1.0 

resv@vcRefAnnoOn               = False 
resv@vcRefMagnitudeF           = 1.0  
resv@vcRefLengthF              = 0.005   
;;=========================================================

res = True
res@gsnDraw=False
res@gsnFrame=False
res@gsnAddCyclic=False
res@gsnCenterString="" ;;for zz and hh
res@gsnLeftStringFontHeightF = 0.012
;res@gsnLeftString=label(nlev*4)
res@gsnRightString=""

res@mpCenterLonF=180
res@mpMaxLonF=359
res@mpMinLonF=1
res@mpMaxLatF=-25
res@mpMinLatF=-75
res@mpMonoFillColor = True
res@mpFillColor = "gray79"
res@cnFillOn=True
res@cnLinesOn=False
;res@cnLineThicknessF=0.1
; res@cnLevelSelectionMode="ManualLevels"
; res@cnMaxLevelValF=var_max
; res@cnMinLevelValF=var_min
; res@cnLevelSpacingF=spa
res@cnLevelSelectionMode="ExplicitLevels"
res@cnLevels       = values
res@cnFillColors       = fill
; res@cnLevelSelectionMode="ExplicitLevels"
; res@cnLevels       = (/-3000,-2500,-2000,-1500,-1000,-500,0,500,1000,1500,2000,2500,3000/)
; res@cnFillColors       = (/10,20,35,50,65,80,110,    140,153,170,190,205,217,230/)

res@cnFillMode = "RasterFill"
res@lbLabelBarOn = False
res@lbBoxLinesOn=False
; res@lbLabelFontHeightF = 0.01
; res@lbLabelStride = 1
; res@pmLabelBarOrthogonalPosF=0.11
res@tmXBLabelFontHeightF=0.0075
res@tmXBLabelDeltaF=-0.5
res@tmYLLabelFontHeightF=0.0075
res@tmYLLabelDeltaF=-0.5
;;----------------------------------------

res@gsnLeftString=label(0)
base(0)=gsn_csm_contour_map(wks,var1,res)  
plotv(0)=gsn_csm_vector(wks,vec1_1,vec1_2,resv)
overlay(base(0),plotv(0))

res@gsnLeftString=label(1)
base(1)=gsn_csm_contour_map(wks,var2,res)  
plotv(1)=gsn_csm_vector(wks,vec2_1,vec2_2,resv)
overlay(base(1),plotv(1))

res@gsnLeftString=label(2)
base(2)=gsn_csm_contour_map(wks,var3,res)  
plotv(2)=gsn_csm_vector(wks,vec3_1,vec3_2,resv)
overlay(base(2),plotv(2))

res@gsnLeftString=label(3)
base(3)=gsn_csm_contour_map(wks,var4,res)  
plotv(3)=gsn_csm_vector(wks,vec4_1,vec4_2,resv)
overlay(base(3),plotv(3))


pres = True
pres@txString = ""
pres@gsnPanelLabelBar = True
;pres@gsnPanelFigureStrings = (/"a","b","c","d","e"/)
;pres@gsnPanelFigureStringsFontHeightF=0.01
; pres@amJust = "Topleft"
pres@pmLabelBarWidthF = 0.8
pres@pmLegendHeightF = 0.6
pres@pmLabelBarParallelPosF = -0.012
pres@lbLabelFontHeightF = 0.012
pres@lbBoxLinesOn=False
pres@lbLabelStride = 25
gsn_panel(wks,base,(/4,1/),pres)

;draw(base(0))
;frame(wks)



end
